@@ -21,7 +21,7 @@
    USA.
 */
 
-#include <QtTest>
+#include <testlib/qtest_zanshin.h>
 
 #include "utils/compositejob.h"
 
@@ -111,7 +111,7 @@ private slots:
 
         auto handler = [&]() {
             FakeJob *job2 = new FakeJob(this);
-            QObject::connect(job2, SIGNAL(result(KJob*)), this, SLOT(handleJobResult(KJob*)));
+            QObject::connect(job2, &KJob::result, this, &CompositeJobTest::handleJobResult);
             compositeJob->addSubjob(job2);
             job2->start();
         };
@@ -135,7 +135,7 @@ private slots:
         compositeJob->setAutoDelete(false);
 
         auto handler = [&]() {
-            compositeJob->emitError("Error reached");
+            compositeJob->emitError(QStringLiteral("Error reached"));
         };
 
         FakeJob *job = new FakeJob(this);
@@ -146,11 +146,11 @@ private slots:
         QTest::qWait(FakeJob::DURATION*2 + 10);
 
         QCOMPARE(compositeJob->error(), static_cast<int>(KJob::UserDefinedError));
-        QCOMPARE(compositeJob->errorText(), QString("Error reached"));
+        QCOMPARE(compositeJob->errorText(), QStringLiteral("Error reached"));
         delete compositeJob;
     }
 };
 
-QTEST_MAIN(CompositeJobTest)
+ZANSHIN_TEST_MAIN(CompositeJobTest)
 
 #include "compositejobtest.moc"
